@@ -3,7 +3,7 @@ package Carton;
 use strict;
 use warnings;
 use 5.008_001;
-use version; our $VERSION = "v0.9_7";
+use version; our $VERSION = "v0.9_8";
 
 use Cwd;
 use Config qw(%Config);
@@ -45,16 +45,10 @@ sub download_from_cpanfile {
 }
 
 sub install_from_cpanfile {
-    my($self, $file) = @_;
+    my($self, $file, $cascade) = @_;
 
-    my @modules;
-    if ($self->lock) {
-        my $tree = $self->build_tree($self->lock->{modules});
-        push @modules, map $_->spec, $tree->children;
-    }
-
-    push @modules, $self->list_dependencies;
-    $self->install_conservative(\@modules, 1)
+    my @modules = $self->list_dependencies;
+    $self->install_conservative(\@modules, $cascade)
         or die "Installing modules failed\n";
 }
 
@@ -72,16 +66,6 @@ sub list_dependencies {
     return map "$_~$hash->{$_}", keys %$hash; # TODO refactor to not rely on string representation
 }
 
-sub install_from_lock {
-    my($self) = @_;
-
-    my $tree = $self->build_tree($self->lock->{modules});
-    my @root = map $_->spec, $tree->children;
-
-    $self->install_conservative(\@root, 0)
-        or die "Installing modules failed\n";
-}
-
 sub dedupe_modules {
     my($self, $modules) = @_;
 
